#define DOCTEST_CONFIG_IMPLEMENT_WITH_MAIN
#include "doctest/doctest.h"

// This is all that is needed to compile a test-runner executable.
// More tests can be added here, or in a new test/*.cpp file.
